@@ -23,7 +23,7 @@ def _screenMainLoop(s):
             s.refresh(f=True)
         try:
             msg = s.q.get(timeout=0.5)
-            sys.stderr.write(s.q.qsize())
+            sys.stderr.write(str(s.q.qsize()))
         except Empty:
             s.refresh()
         if isinstance(msg, list) and len(msg) > 0:
